package jumbo.xml;

import java.awt.BorderLayout;

import com.sun.java.swing.JComponent;
import com.sun.java.swing.JLabel;
import com.sun.java.swing.JPanel;
import com.sun.java.swing.JScrollPane;
import com.sun.java.swing.JTextPane;

import com.sun.java.swing.text.SimpleAttributeSet;

import jumbo.xml.gui.XText;

/** A PCDATA node i.e. no elementType, just contains a string. The elementName
is set to #PCDATA though this cannot be relied on. Note that it is easy
to get muddled about the levels - &lt;FOO&gt;bar&lt;/FOO&gt; is an XNode of elementName
FOO which contains a PCDATANode whose content is bar.
@author P.Murray-Rust, 1998
*/
public class PCDATANode extends XNode {
	String content = null;
/** create a PCDATA node with content
@param String content the string content of the node
*/
	public PCDATANode(String content) {
		super("#PCDATA", content);
		this.content = content;
	}

/** copy constructor
@param PCDATANode node to be copied
*/
	public PCDATANode(PCDATANode pcdataNode) {
		this(pcdataNode.content);
	}

/** is this node's content composed completely of whitespace (uses trim())?
@return boolean true is node's content is whitespace only
*/
	public boolean isWhitespace() {
		return (content.trim().equals(""));
	}


/** Not yet written
@param int type type of component to return
@return JComponent the component 
*/
	public JComponent getDisplayComponent(int type) {
		System.out.println("PCDATA");
		if (displayComponents[type] == null) {
			XText xText = null;
			JComponent component = null;
			try {
				if (type == CONTENT) {
					xText = new XText();
//					addContent(xText, 0);

					xText.setEditable(false);
				} else if (type == ELEMENTNAME) {
					super.getDisplayComponent(ELEMENTNAME);
				} else if (type == ATTRIBUTES) {
					System.out.println("No attributes for PCDATA");

					JPanel jPanel = new JPanel();
					jPanel.setLayout(new BorderLayout());
					jPanel.add(new JLabel("No attributes for PCDATA"));
				} else if (type == XMLCONTENT ||
				    type == PRETTY ||
				    type == TAGGED ||
				    type == UNTAGGED ||
				    type == WHITESPACE) {
					xText = new XText();
					xText.addText(this.getEventStream(type, 0), new SimpleAttributeSet());
					xText.setEditable(false);
					if (type == XMLCONTENT) xText.setEditable(true);
				}
				if (xText != null) {
					displayComponents[type] = new JScrollPane(xText.getJTextPane());
					if (type == XMLCONTENT) contentText = xText;
				} else if (component != null) {
					displayComponents[type] = component;
				}
			} catch (NullPointerException ne) {
				ne.printStackTrace();
			} catch (Exception e) {e.printStackTrace();}
		}
		return displayComponents[type];
	}
		
/** get a title for the node (primarily for display). Uses the first 30 characters
of the content prefixed by "[S]".
@return String the title
*/
	public String getTitle() {
		return "[S]"+content.substring(0,Math.min(30, content.length()));
	}
}